
# Slot: qualifiers


this field can be used to annotate special characteristics of an agent relationship, such as the fact that a given author agent of a publication is the 'corresponding author'

URI: [biolink:contributor_association_qualifiers](https://w3id.org/biolink/vocab/contributor_association_qualifiers)


## Domain and Range

[ContributorAssociation](ContributorAssociation.md) &#8594;  <sub>0..\*</sub> [OntologyClass](OntologyClass.md)

## Parents

 *  is_a: [qualifiers](qualifiers.md)

## Children


## Used by

 * [ContributorAssociation](ContributorAssociation.md)
